%define anolis_release 1
%global	project_name	idxd-config

Name:		accel-config
Version:	4.1.8
Release:	%{anolis_release}%{?dist}
Summary:	Configure accelerator subsystem devices
License:	GPL-2.0-only
URL:		https://github.com/intel/%{project_name}
Source0:	%{URL}/archive/%{name}-v%{version}.tar.gz
Patch1:		1000-fix-problem-for-k8s-use.patch

Requires:	%{name}-libs%{?_isa} = %{version}-%{release}
BuildRequires:	gcc
BuildRequires:	xmlto
BuildRequires:	libtool
BuildRequires:	openssl-devel
BuildRequires:	systemd
BuildRequires:	asciidoc
BuildRequires:	pkgconfig
BuildRequires:	pkgconfig(libkmod)
BuildRequires:	pkgconfig(uuid)
BuildRequires:	pkgconfig(json-c)
BuildRequires:	pkgconfig(libudev)
BuildRequires:	pkgconfig(zlib)
BuildRequires:  autoconf

# accel-config is for configuring Intel DSA (Data-Streaming
# Accelerator) subsystem in the Linux kernel. It supports x86_64 only.
ExclusiveArch:	%{ix86} x86_64

%description
Accel-config is an open-source utility library for controlling and configuring
Intel Data Streaming Accelerator (DSA) and Intel Analytics Accelerator (IAA)
sub-systems within the Linux kernel. It provides a user-friendly interface to
configure, manage, and monitor these sub-systems.

The library supports a range of DSA and IAA hardware accelerators, including
FPGA-based accelerators, which can perform complex data processing tasks such
as compression, encryption, and data analytics. The library enables users to
configure these accelerators to optimize performance for their specific use case.

Accel-config has several key features, including:

Configuration management: Accel-config provides a unified interface to
configure, manage, and monitor DSA and IAA sub-systems within the Linux kernel.
Users can modify the configuration of individual hardware accelerators and
pipelines to optimize performance.

Performance monitoring: Accel-config includes a set of monitoring tools that
enable users to monitor the performance of DSA and IAA sub-systems in real-time.
This can help identify performance bottlenecks, optimize system configuration,
and improve overall system performance.

Debugging tools: Accel-config provides a set of debugging tools that enable
users to diagnose and troubleshoot issues with DSA and IAA sub-systems. This
includes tools for tracing data flow through pipelines, identifying hardware
faults, and testing individual hardware accelerators.

Scalability: Accel-config is designed to scale to large-scale deployments,
supporting multiple hardware accelerators and pipelines. It can be integrated
with existing monitoring and management tools to provide a unified interface
for managing complex data processing systems.

Overall, Accel-config is a powerful tool for managing and optimizing Intel DSA
and IAA sub-systems within the Linux kernel. It provides a user-friendly
interface for configuring and monitoring these sub-systems, enabling users to
optimize performance for their specific use case.


%package libs
Summary:	Configuration library for accelerator subsystem devices
License:	LGPL-2.1-only
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description libs
Libraries for %{name}.

%package test
Summary:        Tests for accel-config
License:        GPL-2.0-only
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description test
Tests for accel-config command.

%package devel
Summary:	Development files for libaccfg
License:	LGPLv2.1
Group:		Development/Libraries
Requires:	%{name}-libs = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package doc
Summary: Documentation files for %{name}
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}

%prep
%autosetup -n idxd-config-%{name}-v%{version} -p1

%build
echo %{version} > version
./autogen.sh
%configure --disable-static --disable-silent-rules --enable-test
%make_build

%install
%make_install
find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} ';'

%generate_compatibility_deps

%check
make check

%files
%dir %{abidir}
%{_bindir}/%{name}
%{abidir}/libaccel-config.dump
%license licenses/accel-config-licenses LICENSE_GPL_2_0
%license Documentation/COPYING licenses/BSD-MIT licenses/CC0
%{_mandir}/man1/%{name}*
%{_sysconfdir}/%{name}/contrib/configs/*

%files libs
%license Documentation/COPYING licenses/BSD-MIT licenses/CC0
%license licenses/accel-config-licenses accfg/lib/LICENSE_LGPL_2_1
%{_libdir}/lib%{name}.so.*

%files devel
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/lib%{name}.pc
%license Documentation/COPYING

%files test
%license Documentation/COPYING LICENSE_GPL_2_0
%doc test/README.md
%{_libexecdir}/accel-config/test/*

%files doc
%doc README.md
%doc Documentation/accfg/a*
%doc Documentation/manpage-base.xsl Documentation/manpage-normal.xsl

%changelog
* Mon Feb 17 2025 Zhao Hang <wb-zh951434@alibaba-inc.com> - 4.1.8-1
- Refer to CentOS Stream accel-config-4.1.8-2 (tdawson@redhat.com)
- Update some description (xuchun.shang@linux.alibaba.com)

* Mon Sep 25 2023 Wenlong Zhang <zhangwenlong@loongson.cn> - 3.5.1-4
- Add loongarch64 support

* Fri Sep 22 2023 Xingrui Yi <yixingrui@linux.alibaba.com> - 3.5.1-3
- Fix for k8s use

* Wed Apr 12 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 3.5.1-2
- Update some description

* Fri Dec 09 2022 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 3.5.1-1
- update to 3.5.1 and fix bug

* Tue May 10 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.4.6.4-1
- init from upstream
